%define _prefix /scisoft

# Need to filter out certain internal libraries from the RPM requires entries.
%global __requires_exclude perl.*(Mylib|_theli|SEXconf|PDL|PGPLOT|Tie::IxHash|Astro::FITS).*

# Ignore errors when brp-python-bytecompile is executed by RPM.
%global _python_bytecompile_errors_terminate_build 0

# The debuginfo package does not build due to errors, so disable it.
%define debug_package %{nil}

Name:           scisoft-theli
Version:        1.9.5
Release:        1%{?dist}
Summary:        Theli is a tool for the automated reduction of astronomical images.
Distribution:   Scisoft
Group:          Applications/Scientific
License:        GPL and ESO
Packager:       Carlos Guirao <cguirao@eso.org>
URL:            http://www.astro.uni-bonn.de/~theli/
Source0:        http://www.astro.uni-bonn.de/~theli/gui/download/theli-%{version}.tgz
Source1:        http://www.astro.uni-bonn.de/~theli/gui/download/gui-2.10.3.tgz

BuildRequires:  gcc-c++
BuildRequires:  python2-devel
BuildRequires:  python-matplotlib
BuildRequires:  plplot
BuildRequires:  qt3-devel
BuildRequires:  gsl-devel
BuildRequires:  fftw-devel
BuildRequires:  libtiff-devel
BuildRequires:  CCfits-devel
BuildRequires:  bzip2-devel
BuildRequires:  cairo-devel
BuildRequires:  libjpeg-turbo-devel
%if 0%{?centos} == 7 || 0%{?rhel} == 7
BuildRequires:  numpy
Requires:       numpy
%else
BuildRequires:  python2-numpy
Requires:       python2-numpy
%endif
Requires:       scisoft-common
Requires:       scamp
Requires:       csh
Requires:       gawk
Requires:       wget
Requires:       scipy
Requires:       ImageMagick
Requires:       libpng
Requires:       python-astropy
Requires:       pyfits

%description
THELI is a tool for the automated reduction of astronomical images.
It comes in two flavours which are maintained independently:
- A graphical user interface
  The THELI GUI is a very flexible and interactive tool, offering a broad 
  range of routines for optical, near- and mid-infrared images. 
  Many different instruments from observatories world-wide are pre-configured. 
  Recommended for the general user.
- A set of command-line based scripts 

%prep
%setup -q -n theli-%{version}
%setup -q -T -b 1 -n gui-2.10.3
sed -e 's|qmake-qt3|qmake|g' -i install.sh

# Remove broken link.
rm -f %{_builddir}/gui-2.10.3/.#updates

%build
# Theli does not provide an easy to use build procedure that will allow building
# within a build directory and installing it into the buildroot for packaging.
# Therefore we are forced to rely on the user that is running this RPM build to
# have sudo rights, to prepare the files directly in /scisoft.
sudo install -m 755 -d %{_datadir}/theli
sudo cp -r %{_builddir}/theli-%{version} %{_datadir}/theli/
sudo cp -r %{_builddir}/gui-2.10.3 %{_datadir}/theli/
cd %{_datadir}/theli/theli-%{version}/pipesetup
sudo ./install.sh -m ALL
cd %{_datadir}/theli/gui-2.10.3
sudo sed -e '1 aexport QTDIR="/usr/%{_lib}/qt-3.3"' -i ./install.sh
sudo sed -e '1 aexport PATH="$PATH:/usr/%{_lib}/qt-3.3/bin"' -i ./install.sh
sudo ./install.sh
# The installation script might not return an error code, so check that we
# really have the binary built.
test -f %{_datadir}/theli/gui/theli || exit 1
sudo chown -R root:root %{_datadir}/theli
sudo chmod -R g+r,o+r %{_datadir}/theli

%install
install -m 755 -d %{buildroot}%{_bindir}
install -m 755 -d %{buildroot}%{_datadir}
cp -r %{_datadir}/theli %{buildroot}%{_datadir}
# Create a symbolic link to scamp where Theli expects it.
%if %{_arch} == x86_64
ln -s /usr/bin/scamp %{buildroot}%{_datadir}/theli/theli/bin/Linux_64/scamp
%else
ln -s /usr/bin/scamp %{buildroot}%{_datadir}/theli/theli/bin/Linux/scamp
%endif
ln -s %{_datadir}/theli/gui/theli %{buildroot}%{_bindir}/theli

%files
%{_prefix}
%defattr(-,root,root,-)

%clean
sudo rm -rf %{_datadir}/theli

%changelog
* Mon Mar 19 2018 Artur Szostak <aszostak@partner.eso.org> 1.9.5
- Integrated into automated build system for Scisoft.
- Removed dependency on a particular version of Matplotlib, since this is not
  required according to Theli's documentation.
- Updated to using standard RPM macros for path locations.

* Thu May 4 2017 Artur Szostak <aszostak@partner.eso.org> 1.9.5-2
- Making sure Matplotlib version is newer or equal to 1.3 (PIPE-5190).
- Adding missing dependencies for Python, cairo and JPEG development packages.

* Tue Oct 18 2016 Artur Szostak <aszostak@partner.eso.org> 1.9.5-1
- Updating to version 1.9.5, which actually builds on Fedora 24 with GSL 2.1.

* Thu Nov 14 2013 <cguirao@eso.org>
- adapted to SCISOFT 
